@@ -30,6 +30,7 @@
 #include <gio/gwin32inputstream.h>
 #include <gio/gwin32outputstream.h>
 #else /* !G_OS_WIN32 */
+#include <arpa/inet.h>
 #include <netinet/in.h>
 #include <gio/gunixinputstream.h>
 #include <gio/gunixoutputstream.h>
@@ -40,7 +41,7 @@
 #include <glib/gi18n.h>
 #include <gnome-keyring.h>
 
-#define SSH_READ_TIMEOUT 40   /* seconds */
+static const int SSH_READ_TIMEOUT = 40; /* seconds */
 
 #ifdef HAVE_GRANTPT
 /* We only use this on systems with unix98 ptys */
